# Finde Wanderrucksack
```
salewa = Dims(rucksack)
salewa.rückennetz = True
salewa.stauraum = 28
salewa.stauraum = improve(salewa.stauraum, 'mehr')
salewa.gewicht = 970 g
salewa.stöcker = True
salewa.save()
```

```
def improve(s: Stauraum):
  xs = get_available_sizes()
  return [x for x in xs if x > s]
```
